#!/bin/bash
# generate base names base|otu
alias showlog='tac /var/log/user.log | grep -B 10000 -m 1 "Isu: \[PINFO\]   1 ." | tac'
alias is_rescue='[ -f /proc/device-tree/board/rescue-mode ] && echo $(cat /proc/device-tree/board/rescue-mode) || echo "no"'


source /usr/lib/otu_functions

IS_OTU_MODE="NO"
is_cotu_hw
if [ $? -eq 1 ] ; then
	IS_OTU_MODE="YES"
fi

if [ "$IS_OTU_MODE" == "YES" ] ; then
    INFO_OTU_BOARD=$(hexdump /proc/device-tree/board/info-otu-board -n 4 -e '"%d"')
    export CFG_PLATFORM_NAME="Otu5000"
	export CFG_MKT_PLATFORM_NAME="Otu5000"
    export CFG_PLATFORM_HOSTNAME="otu-5000"
    export CFG_PLATFORM_FRIENDLY_NAME="OTU 5000"
    export INFO_OTU_BOARD
fi
